editpyxl
========

editpyxl is a Python library to non-destructively edit Excel 2010 xlsx/xlsm files.

The purpose is to edit excel files without otherwise modifying the excel document, to allow for efficient and quick
edits of an excel file.

Many thanks to openpyxl for their hard work in developing a tool to read and writing excel files.
https://bitbucket.org/ericgazoni/openpyxl



Official documentation
======================

The homepage is http://editpyxl.readthedocs.org
You will find:

* every installation methods
* the official documentation
* code examples
* instructions for contributing
